@@ -3,7 +3,7 @@
 import sys
 import appcli
 from appdirs import AppDirs
-from inform import Error
+from inform import Error, format_range
 from pathlib import Path
 
 app_dirs = AppDirs("stepwise_mol_bio")
@@ -21,9 +21,6 @@ class Main(appcli.App):
         except Error as err:
             err.report()
 
-    def load(self):
-        appcli.load(self)
-
 
 
 class StepwiseMolBioError(Error):
@@ -61,3 +58,7 @@ def comma_list(x):
 def comma_set(x):
     return {x.strip() for x in x.split(',')}
 
+def require_reagent(rxn, reagent):
+    if reagent not in rxn:
+        raise UsageError(f"reagent table missing {reagent!r}")
+
